@@ -1,6 +1,6 @@
 //===----------------------------------------------------------------------===//
 //
-// Copyright (c) 2012, 2013, 2014, 2015 The University of Utah
+// Copyright (c) 2012, 2013, 2014, 2015, 2017 The University of Utah
 // All rights reserved.
 //
 // This file is distributed under the University of Illinois Open Source
@@ -247,7 +247,7 @@ void ClassTemplateToClass::rewriteClassTemplateDecls(void)
          E = TheClassTemplateDecl->redecls_end();
        I != E; ++I) {
     const TemplateParameterList *TPList = (*I)->getTemplateParameters();
-    SourceLocation LocStart = (*I)->getLocStart();
+    SourceLocation LocStart = (*I)->getBeginLoc();
     removeTemplateAndParameter(LocStart, TPList);
   }
 }
