@@ -106,7 +106,8 @@ bool RNFStatementVisitor::VisitCallExpr(CallExpr *CallE)
       return true;
   }
 
-  if ((std::find(ConsumerInstance->ValidCallExprs.begin(),
+  if (CurrentStmt &&
+      (std::find(ConsumerInstance->ValidCallExprs.begin(),
                  ConsumerInstance->ValidCallExprs.end(), CallE)
           == ConsumerInstance->ValidCallExprs.end()) &&
       !ConsumerInstance->CallExprQueue.empty()) {
@@ -215,6 +216,11 @@ void RemoveNestedFunction::getNewIntTmpVariable(std::string &VarStr)
   VarStr = "int " + VarStr;
 }
 
+void RemoveNestedFunction::getNewAutoTmpVariable(std::string &VarStr)
+{
+  VarStr = "auto " + VarStr;
+}
+
 void RemoveNestedFunction::addNewTmpVariable(ASTContext &ASTCtx)
 {
   std::string VarStr;
@@ -437,6 +443,12 @@ void RemoveNestedFunction::getNewTmpVariableStr(ASTContext &ASTCtx,
     }
   }
 
+  // We can't resolve dependent scoped DeclRefExpr, and just make it
+  // type of int.
+  if (dyn_cast<DependentScopeDeclRefExpr>(E)) {
+    return getNewAutoTmpVariable(VarStr);
+  }
+
   const Type *CalleeType = E->getType().getTypePtr();
   // template <class T1, class T2> struct S {
   //   T1 x; T2 y;
