@@ -323,7 +323,7 @@ bool ReplaceFunctionDefWithDecl::isMacroExpansion(const FunctionDecl *FD)
   const Stmt *Body = FD->getBody();
   if (!Body)
     return false;
-  return SrcManager->isMacroBodyExpansion(Body->getLocStart());
+  return SrcManager->isMacroBodyExpansion(Body->getBeginLoc());
 }
 
 void ReplaceFunctionDefWithDecl::addOneFunctionDef(const FunctionDecl *FD)
