@@ -69,6 +69,8 @@ public:
 
   bool TraverseConstructorInitializer(CXXCtorInitializer *Init);
 
+  bool TraverseParmVarDecl(ParmVarDecl *PV);
+
   unsigned int getNumStmts(void) {
     return NumStmts;
   }
@@ -186,6 +188,11 @@ bool SimpleInlinerCollectionVisitor::TraverseConstructorInitializer(
   return true;
 }
 
+bool SimpleInlinerCollectionVisitor::TraverseParmVarDecl(ParmVarDecl *PV)
+{
+  return true;
+}
+
 bool SimpleInlinerFunctionVisitor::VisitReturnStmt(ReturnStmt *RS)
 {
   ConsumerInstance->ReturnStmts.push_back(RS);
