@@ -1,6 +1,6 @@
 ## -*- mode: Perl -*-
 ##
-## Copyright (c) 2012, 2013, 2015 The University of Utah
+## Copyright (c) 2012, 2013, 2015, 2016, 2018 The University of Utah
 ## All rights reserved.
 ##
 ## This file is distributed under the University of Illinois Open Source
@@ -71,7 +71,7 @@ sub run_clang_delta ($) {
 # utility code to help us replace the nth occurrence of a pattern
 $replace_cont = 0;
 $matched = 0;
-sub replace_aux ($$$) { 
+sub replace_aux ($$$) {
     my ($index,$original,$replacement) = @_;
     $replace_cont++;
     $matched = 1;
@@ -86,12 +86,6 @@ sub read_file ($) {
 	$prog .= $line;
     }
     close INF;
-    if (substr($prog, 0, 1) ne " ") {
-	$prog = " $prog";
-    }
-    if (substr ($prog, -1, 1) ne " ") {
-	$prog = "$prog ";
-    }
     return $prog;
 }
 
@@ -130,15 +124,12 @@ sub ncpus () {
     if ($OS eq "MSWin32") {
 	# TODO
     }
-    # Load and use the Sys::CPU module if available, don't complain otherwise
-    # we try this last since it will count hyperthreads not cores
-    return Sys::CPU::cpu_count() if (eval { require Sys::CPU; });
     return 1;
 }
 
 # here we're pretty conservative about the number of parallel
 # processes to use; if the user has some big iron she can specify a
-# higher number using -n
+# higher number using --n
 sub nprocs () {
     my $cpus = ncpus();
     die unless ($cpus >= 1);
