@@ -25,7 +25,8 @@ my $options = "-B -x 2";
 
 sub check_prereqs () {
     my $path;
-    if ($FindBin::RealBin eq abs_path(bindir)) {
+    my $abs_bindir = abs_path(bindir);
+    if ((defined $abs_bindir) && ($FindBin::RealBin eq $abs_bindir)) {
 	# This script is in the installation directory.
 	# Use the installed `unifdef'.
 	$path = libexecdir . "/unifdef";
@@ -48,7 +49,7 @@ sub check_prereqs () {
 }
 
 sub new ($$) {
-    my $index = 0;
+    my $index = -1;
     return \$index;
 }
 
@@ -71,6 +72,19 @@ sub transform ($$$) {
     close INF;
     my @deflist = sort keys %defs;
     my $tmpfile = File::Temp::tmpnam();
+
+    # remove constant ifs
+    if ($index == -1) {
+	my $cmd = "$unifdef -k -o $tmpfile $cfile >/dev/null 2>&1";
+	runit ($cmd);
+	$index++;
+	if (compare($cfile, $tmpfile) == 0) {
+	    goto AGAIN;
+        }
+	File::Copy::move($tmpfile, $cfile);
+	return ($OK, \$index);
+    }
+
   AGAIN:
     print "index = $index\n" if $DEBUG;
     my $DU = (($index % 2) == 0) ? "-D" : "-U";
