@@ -28,23 +28,23 @@ apt-get install -y -qq \
     software-properties-common \
     wget
 
-# Set up for installing LLVM 6.0.
+# Set up for installing LLVM 7.0
 # See <https://wiki.ubuntu.com/ToolChain>.
 # See <http://llvm.org/apt/>.
 add-apt-repository -y \
     ppa:ubuntu-toolchain-r/test
 add-apt-repository -y \
-    'deb http://apt.llvm.org/xenial/ llvm-toolchain-xenial-6.0 main'
+    'deb http://apt.llvm.org/xenial/ llvm-toolchain-xenial-7 main'
 wget -O - http://apt.llvm.org/llvm-snapshot.gpg.key | apt-key add -
 apt-get update -qq
 
-# Install LLVM 6.0.  See file "INSTALL".
+# Install LLVM 7.0.  See file "INSTALL".
 apt-get install -y -qq \
-    llvm-6.0 \
-    llvm-6.0-dev \
-    clang-6.0 \
-    libclang-6.0-dev \
-    clang-format-6.0 \
+    llvm-7 \
+    llvm-7-dev \
+    clang-7 \
+    libclang-7-dev \
+    clang-format-7 \
     libedit-dev
 
 # Install other C-Reduce dependencies.  See file "INSTALL".
@@ -53,7 +53,6 @@ apt-get install -y -qq \
     libfile-which-perl \
     libgetopt-tabular-perl \
     libregexp-common-perl \
-    libsys-cpu-perl \
     libterm-readkey-perl \
     flex \
     build-essential \
